@@ -22,9 +22,13 @@ class SimplePublishModel(models.Model):
             self.publish_time = None
         return super().save(*args, **kwargs)
 
+    def is_published(self):
+        return self.published
+
     def do_publish(self, save=False):
         self.published = True
         self.publish_time = timezone.now()
+        self.unpublish_time = None
         if save:
             self.save()
         return self
@@ -32,6 +36,7 @@ class SimplePublishModel(models.Model):
     def do_unpublish(self, save=False):
         self.published = False
         self.publish_time = None
+        self.unpublish_time = timezone.now()
         if save:
             self.save()
         return self
